@@ -1,6 +1,6 @@
 package Plack::App::TemplateToolkit;
 BEGIN {
-  $Plack::App::TemplateToolkit::VERSION = '0.03';
+  $Plack::App::TemplateToolkit::VERSION = '0.04';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ use Plack::Request 0.9901;
 use Template 2;
 
 use Plack::Util::Accessor
-    qw( root dir_index path extension content_type tt eval_perl pre_process);
+    qw( root dir_index path extension content_type tt eval_perl pre_process process);
 
 sub prepare_app {
     my ($self) = @_;
@@ -29,6 +29,7 @@ sub prepare_app {
     };
 
     $config->{PRE_PROCESS} = $self->pre_process() if $self->pre_process();
+    $config->{PROCESS}     = $self->process()     if $self->process();
 
     # create Template object
     $self->tt( Template->new($config) );
@@ -105,7 +106,7 @@ Plack::App::TemplateToolkit
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
